@@ -277,7 +277,7 @@ Translations = %(pyside_prefix)s/translations
     # Install OpenSSL libs
     for dll in ["libeay32.dll", "ssleay32.dll"]:
         dest_path = os.path.join(exec_prefix, dll)
-        src_path = os.path.join(os.path.join(pyside_path, "openssl"), dll)
+        src_path = os.path.join(pyside_path, "openssl", dll)
         if not os.path.exists(dest_path) and os.path.exists(src_path):
             shutil.copy(src_path, dest_path)
             file_created(dest_path)
